pytilities.geometry.test.vector.VHolder

Package pytilities :: Package geometry :: Package test :: Module vector :: Class VHolder |
[hide private]
[frames] | no frames]

# Class VHolder

source code

    object --+
             |
            VHolder

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| x
| y
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### x Get Method: unreachable.x(self) Set Method: unreachable.x(self, value)

### y Get Method: unreachable.y(self) Set Method: unreachable.y(self, value)